@@ -820,25 +820,24 @@ class S3FileSystem(AsyncFileSystem):
         thisdircache = {}
         for o in out:
             par = self._parent(o["name"])
-            if par not in self.dircache:
-                if par not in sdirs:
-                    sdirs.add(par)
-                    d = False
-                    if len(path) <= len(par):
-                        d = {
-                            "Key": self.split_path(par)[1],
-                            "Size": 0,
-                            "name": par,
-                            "StorageClass": "DIRECTORY",
-                            "type": "directory",
-                            "size": 0,
-                        }
-                        dirs.append(d)
-                    thisdircache[par] = []
-                    ppar = self._parent(par)
-                    if ppar in thisdircache:
-                        if d and d not in thisdircache[ppar]:
-                            thisdircache[ppar].append(d)
+            if par not in sdirs:
+                sdirs.add(par)
+                d = False
+                if len(path) <= len(par):
+                    d = {
+                        "Key": self.split_path(par)[1],
+                        "Size": 0,
+                        "name": par,
+                        "StorageClass": "DIRECTORY",
+                        "type": "directory",
+                        "size": 0,
+                    }
+                    dirs.append(d)
+                thisdircache[par] = []
+                ppar = self._parent(par)
+                if ppar in thisdircache:
+                    if d and d not in thisdircache[ppar]:
+                        thisdircache[ppar].append(d)
             if par in sdirs:
                 thisdircache[par].append(o)
         if not prefix:
@@ -1108,8 +1107,9 @@ class S3FileSystem(AsyncFileSystem):
 
         with open(lpath, "rb") as f0:
             if size < min(5 * 2**30, 2 * chunksize):
+                chunk = f0.read()
                 await self._call_s3(
-                    "put_object", Bucket=bucket, Key=key, Body=f0, **kwargs
+                    "put_object", Bucket=bucket, Key=key, Body=chunk, **kwargs
                 )
                 callback.relative_update(size)
             else:
@@ -1841,7 +1841,12 @@ class S3FileSystem(AsyncFileSystem):
         }
         for path in pathlist:
             self.invalidate_cache(self._parent(path))
-        await self._call_s3("delete_objects", kwargs, Bucket=bucket, Delete=delete_keys)
+        out = await self._call_s3(
+            "delete_objects", kwargs, Bucket=bucket, Delete=delete_keys
+        )
+        # TODO: we report on successes but don't raise on any errors, effectively
+        #  on_error="omit"
+        return [f"{bucket}/{_['Key']}" for _ in out.get("Deleted", [])]
 
     async def _rm_file(self, path, **kwargs):
         bucket, key, _ = self.split_path(path)
@@ -1861,7 +1866,7 @@ class S3FileSystem(AsyncFileSystem):
         files = [p for p in paths if self.split_path(p)[1]]
         dirs = [p for p in paths if not self.split_path(p)[1]]
         # TODO: fails if more than one bucket in list
-        await _run_coros_in_chunks(
+        out = await _run_coros_in_chunks(
             [
                 self._bulk_delete(files[i : i + 1000])
                 for i in range(0, len(files), 1000)
@@ -1874,6 +1879,7 @@ class S3FileSystem(AsyncFileSystem):
             (self.invalidate_cache(p), self.invalidate_cache(self._parent(p)))
             for p in paths
         ]
+        return sum(out, [])
 
     async def _is_bucket_versioned(self, bucket):
         return (await self._call_s3("get_bucket_versioning", Bucket=bucket)).get(
@@ -2298,21 +2304,6 @@ class S3AsyncStreamedFile(AbstractAsyncStreamedFile):
         return await self.r.read(length)
 
 
-class S3AsyncStreamedFile(AbstractAsyncStreamedFile):
-    def __init__(self, fs, path, mode):
-        self.fs = fs
-        self.path = path
-        self.mode = mode
-        self.r = None
-
-    async def read(self, length=-1):
-        if self.r is None:
-            bucket, key, gen = self.fs.split_path(self.path)
-            r = await self.fs._call_s3("get_object", Bucket=bucket, Key=key)
-            self.r = r["Body"]
-        return await self.r.read(length)
-
-
 def _fetch_range(fs, bucket, key, version_id, start, end, req_kw=None):
     if req_kw is None:
         req_kw = {}
