@@ -374,7 +374,7 @@ def test_checksum(s3):
     s3.checksum(path1, refresh=True)
 
 
-test_xattr_sample_metadata = {"test_xattr": "1"}
+test_xattr_sample_metadata = {"testxattr": "1"}
 
 
 def test_xattr(s3):
@@ -389,7 +389,7 @@ def test_xattr(s3):
         },
     }
 
-    sync(
+    resp = sync(
         s3.loop,
         s3.s3.put_object,
         Bucket=bucket,
@@ -406,18 +406,16 @@ def test_xattr(s3):
         in sync(s3.loop, s3.s3.get_object_acl, Bucket=bucket, Key=key)["Grants"]
     )
 
-    assert (
-        s3.getxattr(filename, "test_xattr") == test_xattr_sample_metadata["test_xattr"]
-    )
-    assert s3.metadata(filename) == {"test-xattr": "1"}  # note _ became -
+    assert s3.getxattr(filename, "testxattr") == test_xattr_sample_metadata["testxattr"]
+    assert s3.metadata(filename) == {"testxattr": "1"}  # note _ became -
 
     s3file = s3.open(filename)
-    assert s3file.getxattr("test_xattr") == test_xattr_sample_metadata["test_xattr"]
-    assert s3file.metadata() == {"test-xattr": "1"}  # note _ became -
+    assert s3file.getxattr("testxattr") == test_xattr_sample_metadata["testxattr"]
+    assert s3file.metadata() == {"testxattr": "1"}  # note _ became -
 
-    s3file.setxattr(test_xattr="2")
-    assert s3file.getxattr("test_xattr") == "2"
-    s3file.setxattr(**{"test_xattr": None})
+    s3file.setxattr(testxattr="2")
+    assert s3file.getxattr("testxattr") == "2"
+    s3file.setxattr(**{"testxattr": None})
     assert s3file.metadata() == {}
     assert s3.cat(filename) == body
 
@@ -576,11 +574,13 @@ def test_rm(s3):
     #    s3.rm(test_bucket_name + '/nonexistent')
     with pytest.raises(FileNotFoundError):
         s3.rm("nonexistent")
-    s3.rm(test_bucket_name + "/nested", recursive=True)
+    out = s3.rm(test_bucket_name + "/nested", recursive=True)
+    assert test_bucket_name + "/nested/nested2/file1" in out
     assert not s3.exists(test_bucket_name + "/nested/nested2/file1")
 
     # whole bucket
-    s3.rm(test_bucket_name, recursive=True)
+    out = s3.rm(test_bucket_name, recursive=True)
+    assert test_bucket_name + "/2014-01-01.csv" in out
     assert not s3.exists(test_bucket_name + "/2014-01-01.csv")
     assert not s3.exists(test_bucket_name)
 
@@ -2145,6 +2145,29 @@ def test_shallow_find(s3):
     assert s3.ls(test_bucket_name) == s3.glob(test_bucket_name + "/*")
 
 
+def test_multi_find(s3):
+    s3.mkdir("bucket/test")
+    s3.mkdir("bucket/test/sub")
+    s3.write_text("bucket/test/file.txt", "some_text")
+    s3.write_text("bucket/test/sub/file.txt", "some_text")
+
+    out1 = s3.find("bucket", withdirs=True)
+    out2 = s3.find("bucket", withdirs=True)
+    assert (
+        out1
+        == out2
+        == [
+            "bucket/test",
+            "bucket/test/file.txt",
+            "bucket/test/sub",
+            "bucket/test/sub/file.txt",
+        ]
+    )
+    out1 = s3.find("bucket", withdirs=False)
+    out2 = s3.find("bucket", withdirs=False)
+    assert out1 == out2 == ["bucket/test/file.txt", "bucket/test/sub/file.txt"]
+
+
 def test_version_sizes(s3):
     # protect against caching of incorrect version details
     s3 = S3FileSystem(
